@@ -5,7 +5,7 @@ use warnings;
 use parent qw(DBGp::Client::Response::Simple);
 
 __PACKAGE__->make_attrib_accessors(qw(
-    transaction_id command context_id
+    transaction_id command
 ));
 
 sub contexts {
