@@ -4,8 +4,6 @@ use strict;
 use warnings;
 use parent qw(DBGp::Client::Response::Simple);
 
-use MIME::Base64 qw(decode_base64);
-
 __PACKAGE__->make_attrib_accessors(qw(
     transaction_id command success
 ));
@@ -14,7 +12,7 @@ sub source {
     my $text = DBGp::Client::Parser::_text($_[0]);
     my $encoding = $_[0]->{attrib}{encoding};
 
-    return $encoding eq 'base64' ? decode_base64($text) : $text;
+    return DBGp::Client::Parser::_decode($text, $encoding);
 }
 
 1;
